# coding: utf-8
u"""Модели приложения логирования СМЭВ."""
import datetime

from django.db import models

from m3.db import BaseObjectModel


class SmevLog(BaseObjectModel):
    u"""Логи СМЭВ web-сервисов."""

    IS_SMEV = 0
    IS_NOT_SMEV = 1
    INTERACTION_TYPES = (
        (IS_SMEV, u'СМЭВ'),
        (IS_NOT_SMEV, u'Не СМЭВ'),
    )

    service_address = models.CharField(
        u'Адрес сервиса', max_length=250, null=True, blank=True)

    method_name = models.CharField(
        u'Код метода', max_length=250, null=True, blank=True)

    method_verbose_name = models.CharField(
        u'Наименование метода', max_length=250, null=True, blank=True)

    request = models.TextField(u'SOAP запрос', null=True, blank=True)
    response = models.TextField(u'SOAP ответ', null=True, blank=True)
    error = models.TextField(u'Возникшая ошибка', null=True, blank=True)

    time = models.DateTimeField(
        u'Время СМЭВ запроса', default=datetime.datetime.now)

    interaction_type = models.PositiveSmallIntegerField(
        u'Вид взаимодействия', choices=INTERACTION_TYPES, default=IS_SMEV)

    class Meta:
        verbose_name = u'Лог запросов СМЭВ'
        verbose_name_plural = u'Логи запросов СМЭВ'
